@@ -20,7 +20,7 @@ def _chunk_dfs(geoms_to_chunk, geoms_full, n_jobs):
 
 
 def _index_n_query(geoms1, geoms2):
-    # Pick largest for STRTree, query_bulk the smallest
+    # Pick largest for STRTree, query the smallest
     if geoms1.shape[0] > geoms2.shape[0]:
         large = geoms1
         small = geoms2
@@ -28,7 +28,7 @@ def _index_n_query(geoms1, geoms2):
         large = geoms2
         small = geoms1
     # Build tree + query
-    qry_polyIDs, tree_polyIDs = large.sindex.query_bulk(small, predicate="intersects")
+    qry_polyIDs, tree_polyIDs = large.sindex.query(small, predicate="intersects")
     # Remap IDs to global
     large_global_ids = large.iloc[tree_polyIDs].index.values
     small_global_ids = small.iloc[qry_polyIDs].index.values
@@ -43,15 +43,13 @@ def _chunk_polys(id_pairs, geoms_left, geoms_right, n_jobs):
     chunk_size = id_pairs.shape[0] // n_jobs + 1
     for i in range(n_jobs):
         start = i * chunk_size
-        chunk1 = geoms_left.values.data[id_pairs[start : start + chunk_size, 0]]
-        chunk2 = geoms_right.values.data[id_pairs[start : start + chunk_size, 1]]
+        chunk1 = geoms_left.array[id_pairs[start : start + chunk_size, 0]]
+        chunk2 = geoms_right.array[id_pairs[start : start + chunk_size, 1]]
         yield chunk1, chunk2
 
 
 def _intersect_area_on_chunk(geoms1, geoms2):
-    import pygeos
-
-    areas = pygeos.area(pygeos.intersection(geoms1, geoms2))
+    areas = geoms1.intersection(geoms2).area
     return areas
 
 
@@ -62,7 +60,7 @@ def _area_tables_binning_parallel(source_df, target_df, n_jobs=-1):
 
     NOTE: currently, the largest df is chunked and the other one is shipped in
     full to each core; within each process, the spatial index is built for the
-    largest set of geometries, and the other one used for `query_bulk`
+    largest set of geometries, and the other one used for `query`
 
     Parameters
     ----------
@@ -76,7 +74,7 @@ def _area_tables_binning_parallel(source_df, target_df, n_jobs=-1):
 
     Returns
     -------
-    tables : scipy.sparse.dok_matrix
+    tables : scipy.sparse.csr_matrix
 
     """
     from joblib import Parallel, delayed, parallel_backend
@@ -125,7 +123,7 @@ def _area_tables_binning_parallel(source_df, target_df, n_jobs=-1):
         )
     areas = np.concatenate(worker_out)
 
-    # Build DOK table
+    # Build CSR table
     table = coo_matrix(
         (
             areas,
@@ -134,7 +132,7 @@ def _area_tables_binning_parallel(source_df, target_df, n_jobs=-1):
         shape=(df1.shape[0], df2.shape[0]),
         dtype=np.float32,
     )
-    table = table.todok()
+    table = table.tocsr()
     return table
 
 
@@ -161,7 +159,7 @@ def _area_tables_binning(source_df, target_df, spatial_index):
 
     Returns
     -------
-    tables : scipy.sparse.dok_matrix
+    tables : scipy.sparse.csr_matrix
 
     """
     if _check_crs(source_df, target_df):
@@ -180,9 +178,9 @@ def _area_tables_binning(source_df, target_df, spatial_index):
             spatial_index = "target"
 
     if spatial_index == "source":
-        ids_tgt, ids_src = df1.sindex.query_bulk(df2.geometry, predicate="intersects")
+        ids_tgt, ids_src = df1.sindex.query(df2.geometry, predicate="intersects")
     elif spatial_index == "target":
-        ids_src, ids_tgt = df2.sindex.query_bulk(df1.geometry, predicate="intersects")
+        ids_src, ids_tgt = df2.sindex.query(df1.geometry, predicate="intersects")
     else:
         raise ValueError(
             f"'{spatial_index}' is not a valid option. Use 'auto', 'source' or 'target'."
@@ -199,7 +197,7 @@ def _area_tables_binning(source_df, target_df, spatial_index):
         dtype=np.float32,
     )
 
-    table = table.todok()
+    table = table.tocsr()
 
     return table
 
@@ -226,7 +224,7 @@ def _area_interpolate_binning(
         [Optional. Default=None] Columns in dataframes for extensive variables
     intensive_variables : list
         [Optional. Default=None] Columns in dataframes for intensive variables
-    table : scipy.sparse.dok_matrix
+    table : scipy.sparse.csr_matrix
         [Optional. Default=None] Area allocation source-target correspondence
         table. If not provided, it will be built from `source_df` and
         `target_df` using `tobler.area_interpolate._area_tables_binning`
@@ -249,8 +247,6 @@ def _area_interpolate_binning(
         [Optional. Default=1] Number of processes to run in parallel to
         generate the area allocation. If -1, this is set to the number of CPUs
         available. If `table` is passed, this is ignored.
-        NOTE: as of Jan'21 multi-core functionality requires master versions
-        of `pygeos` and `geopandas`.
     categorical_variables : list
         [Optional. Default=None] Columns in dataframes for categorical variables
 
@@ -305,19 +301,19 @@ def _area_interpolate_binning(
         else:
             table = _area_tables_binning_parallel(source_df, target_df, n_jobs=n_jobs)
 
-    den = source_df.area.values
-    if allocate_total:
-        den = np.asarray(table.sum(axis=1))
-    den = den + (den == 0)
-    den = 1.0 / den
-    n = den.shape[0]
-    den = den.reshape((n,))
-    den = diags([den], [0])
-    weights = den.dot(table)  # row standardize table
-
     dfs = []
     extensive = []
     if extensive_variables:
+        den = source_df.area.values
+        if allocate_total:
+            den = np.asarray(table.sum(axis=1))
+        den = den + (den == 0)
+        den = 1.0 / den
+        n = den.shape[0]
+        den = den.reshape((n,))
+        den = diags([den], [0])
+        weights = den.dot(table)  # row standardize table
+
         for variable in extensive_variables:
             vals = _nan_check(source_df, variable)
             vals = _inf_check(source_df, variable)
@@ -329,15 +325,15 @@ def _area_interpolate_binning(
         extensive = np.array(extensive)
         extensive = pd.DataFrame(extensive.T, columns=extensive_variables)
 
-    area = np.asarray(table.sum(axis=0))
-    den = 1.0 / (area + (area == 0))
-    n, k = den.shape
-    den = den.reshape((k,))
-    den = diags([den], [0])
-    weights = table.dot(den)
-
     intensive = []
     if intensive_variables:
+        area = np.asarray(table.sum(axis=0))
+        den = 1.0 / (area + (area == 0))
+        n, k = den.shape
+        den = den.reshape((k,))
+        den = diags([den], [0])
+        weights = table.dot(den)
+
         for variable in intensive_variables:
             vals = _nan_check(source_df, variable)
             vals = _inf_check(source_df, variable)
